@@ -223,13 +223,26 @@ error:
 /* _ped_Device -> PedDevice functions */
 PedDevice *_ped_Device2PedDevice(PyObject *s) {
     _ped_Device *dev = (_ped_Device *) s;
+    PedDevice *ret;
 
     if (dev == NULL) {
         PyErr_SetString(PyExc_TypeError, "Empty _ped.Device()");
         return NULL;
     }
 
-    return ped_device_get(dev->path);
+    ret = ped_device_get(dev->path);
+    if (ret == NULL) {
+        if (partedExnRaised) {
+            partedExnRaised = 0;
+
+            if (!PyErr_ExceptionMatches(PartedException) &&
+                !PyErr_ExceptionMatches(PyExc_NotImplementedError))
+                PyErr_SetString(DeviceException, partedExnMessage);
+        }
+        else
+            PyErr_Format(DeviceException, "Could not find device for path %s", dev->path);
+    }
+    return ret;
 }
 
 /* PedDevice -> _ped_Device functions */
@@ -297,8 +310,6 @@ PedDisk *_ped_Disk2PedDisk(PyObject *s) {
 
 _ped_Disk *PedDisk2_ped_Disk(PedDisk *disk) {
     _ped_Disk *ret = NULL;
-    _ped_Device *dev = NULL;
-    PyObject *args = NULL;
 
     if (disk == NULL) {
         PyErr_SetString(PyExc_TypeError, "Empty PedDisk()");
@@ -306,31 +317,23 @@ _ped_Disk *PedDisk2_ped_Disk(PedDisk *disk) {
     }
 
     ret = (_ped_Disk *) _ped_Disk_Type_obj.tp_new(&_ped_Disk_Type_obj, NULL, NULL);
-    if (!ret)
+    if (!ret) {
+        ped_disk_destroy(disk);
         return (_ped_Disk *) PyErr_NoMemory();
-
+    }
     ret->ped_disk = disk;
 
-    if ((dev = PedDevice2_ped_Device(disk->dev)) == NULL)
+    ret->dev = (PyObject *) PedDevice2_ped_Device(disk->dev);
+    if (!ret->dev)
         goto error;
 
-    args = Py_BuildValue("(O)", (PyObject *) dev);
-    if (args == NULL) {
+    ret->type = (PyObject *) PedDiskType2_ped_DiskType(disk->type);
+    if (!ret->type)
         goto error;
-    }
-
-    if (_ped_Disk_Type_obj.tp_init((PyObject *) ret, args, NULL)) {
-        goto error;
-    }
-
-    Py_DECREF(args);
-    Py_DECREF(dev);
 
     return ret;
 
 error:
-    Py_XDECREF(args);
-    Py_XDECREF(dev);
     Py_DECREF(ret);
     return NULL;
 }
@@ -353,7 +356,7 @@ PedDiskType *_ped_DiskType2PedDiskType(PyObject *s) {
     return ret;
 }
 
-_ped_DiskType *PedDiskType2_ped_DiskType(PedDiskType *type) {
+_ped_DiskType *PedDiskType2_ped_DiskType(const PedDiskType *type) {
     _ped_DiskType *ret = NULL;
 
     if (type == NULL) {
@@ -596,7 +599,7 @@ PedPartition *_ped_Partition2PedPartition(_ped_Partition *s) {
 }
 
 _ped_Partition *PedPartition2_ped_Partition(PedPartition *part,
-        _ped_Disk *pydisk) {
+                                            _ped_Disk *pydisk) {
     _ped_Partition *ret = NULL;
 
     if (part == NULL) {
