@@ -25,6 +25,8 @@
 import parted
 import _ped
 
+from decorators import localeC
+
 class Constraint(object):
     """Constraint()
 
@@ -34,6 +36,7 @@ class Constraint(object):
        constraint operations can raise CreateException if creating temporary
        objects fails, or ArithmeticError if an error occurs during
        calculations."""
+    @localeC
     def __init__(self, *args, **kwargs):
         """Create a new Constraint object.  There are many different ways to
            create a Constraint, all depending on the parameters passed to
@@ -92,20 +95,42 @@ class Constraint(object):
         c1 = self.getPedConstraint()
         c2 = other.getPedConstraint()
 
-        return self.minSize != other.minSize or self.maxSize != other.maxSize or c1.start_align != c2.start_align or c1.end_align != c2.end_align or c1.start_range != c2.start_range or c1.end_range != c2.end_range
+        return self.minSize != other.minSize \
+                or self.maxSize != other.maxSize \
+                or c1.start_align != c2.start_align \
+                or c1.end_align != c2.end_align \
+                or c1.start_range != c2.start_range \
+                or c1.end_range != c2.end_range
 
-    startAlign = property(lambda s: parted.Alignment(PedAlignment=s.__constraint.start_align), lambda s, v: setattr(s.__constraint, "start_align", v.getPedAlignment()))
-    endAlign = property(lambda s: parted.Alignment(PedAlignment=s.__constraint.end_align), lambda s, v: setattr(s.__constraint, "end_align", v.getPedAlignment()))
-    startRange = property(lambda s: parted.Geometry(PedGeometry=s.__contraint.start_range), lambda s, v: setattr(s.__constraint, "start_range", v.getPedGeometry()))
-    endRange = property(lambda s: parted.Geometry(PedGeometry=s.__contraint.end_range), lambda s, v: setattr(s.__constraint, "end_range", v.getPedGeometry()))
-    minSize = property(lambda s: s.__constraint.min_size, lambda s, v: setattr(s.__constraint, "min_size", v))
-    maxSize = property(lambda s: s.__constraint.max_size, lambda s, v: setattr(s.__constraint, "max_size", v))
+    startAlign = property(
+            lambda s: parted.Alignment(PedAlignment=s.__constraint.start_align),
+            lambda s, v: setattr(s.__constraint, "start_align", v.getPedAlignment()))
+
+    endAlign = property(
+            lambda s: parted.Alignment(PedAlignment=s.__constraint.end_align),
+            lambda s, v: setattr(s.__constraint, "end_align", v.getPedAlignment()))
+
+    startRange = property(
+            lambda s: parted.Geometry(PedGeometry=s.__constraint.start_range),
+            lambda s, v: setattr(s.__constraint, "start_range", v.getPedGeometry()))
+
+    endRange = property(
+            lambda s: parted.Geometry(PedGeometry=s.__constraint.end_range),
+            lambda s, v: setattr(s.__constraint, "end_range", v.getPedGeometry()))
+
+    minSize = property(
+            lambda s: s.__constraint.min_size,
+            lambda s, v: setattr(s.__constraint, "min_size", v))
+
+    maxSize = property(
+            lambda s: s.__constraint.max_size,
+            lambda s, v: setattr(s.__constraint, "max_size", v))
 
     def __str__(self):
         s = ("parted.Constraint instance --\n"
              "  startAlign: %(startAlign)r  endAlign: %(endAlign)r\n"
              "  startRange: %(startRange)r  endRange: %(endRange)r\n"
-             "  minSize: %(minSize)s  maxSize: %(maxSize)\n"
+             "  minSize: %(minSize)s  maxSize: %(maxSize)s\n"
              "  PedConstraint: %(ped)r" %
              {"startAlign": self.startAlign, "endAlign": self.endAlign,
               "startRange": self.startRange, "endRange": self.endRange,
@@ -113,6 +138,7 @@ class Constraint(object):
               "ped": self.__constraint})
         return s
 
+    @localeC
     def intersect(self, b):
         """Return a new constraint that is the intersection of self and the
            provided constraint b.  The returned constraint will therefore be
@@ -120,18 +146,21 @@ class Constraint(object):
            both."""
         return parted.Constraint(PedConstraint=self.__constraint.intersect(b.getPedConstraint()))
 
+    @localeC
     def solveMax(self):
         """Return a new geometry that is the largest region satisfying self.
            There may be more than one solution, and there are no guarantees as
            to which solution will be returned."""
         return parted.Geometry(PedGeometry=self.__constraint.solve_max())
 
+    @localeC
     def solveNearest(self, geom):
         """Return a new geometry that is the nearest region to geom that
            satisfies self.  This function does not guarantee any specific
            meaning of 'nearest'."""
         return parted.Geometry(PedGeometry=self.__constraint.solve_nearest(geom.getPedGeometry()))
 
+    @localeC
     def isSolution(self, geom):
         """Does geom satisfy this constraint?"""
         return self.__constraint.is_solution(geom.getPedGeometry())
