@@ -25,6 +25,7 @@ import _ped
 import parted
 
 from cachedlist import CachedList
+from decorators import localeC
 
 class Disk(object):
     """Disk()
@@ -32,6 +33,7 @@ class Disk(object):
        A Disk object describes a type of device in the system.  Disks
        can hold partitions.  A Disk is a basic operating system-specific
        object."""
+    @localeC
     def __init__(self, device=None, PedDisk=None):
         """Create a new Disk object from the device and type specified.  The
            device is a Device object and type is a string matching a key in
@@ -111,20 +113,74 @@ class Disk(object):
         return partitions
 
     @property
+    @localeC
     def primaryPartitionCount(self):
         """The number of primary partitions on this disk."""
         return self.__disk.get_primary_partition_count()
 
     @property
+    @localeC
     def lastPartitionNumber(self):
         """The last assigned partition number currently on this disk."""
         return self.__disk.get_last_partition_num()
 
     @property
+    @localeC
     def maxPrimaryPartitionCount(self):
         """The maximum number of primary partitions allowed on this disk."""
         return self.__disk.get_max_primary_partition_count()
 
+    @property
+    @localeC
+    def maxSupportedPartitionCount(self):
+        """The maximum number of partitions allowed on this disk."""
+        return self.__disk.get_max_supported_partition_count()
+
+    @property
+    @localeC
+    def partitionAlignment(self):
+        """Partition start address Alignment."""
+        alignment = self.__disk.get_partition_alignment()
+        return parted.Alignment(PedAlignment=alignment)
+
+    @property
+    @localeC
+    def maxPartitionLength(self):
+        """Max Partition Length the disk's label can represent."""
+        return self.__disk.max_partition_length()
+
+    @property
+    @localeC
+    def maxPartitionStartSector(self):
+        """Max Partition Start Sector the disk's label can represent."""
+        return self.__disk.max_partition_start_sector()
+
+    @localeC
+    def getFlag(self, flag):
+        """Get the value of a particular flag on the disk.  Valid flags
+           are the _ped.DISK_* constants.  See _ped.disk_flag_get_name() and
+           _ped.disk_flag_get_by_name() for more help working with disk flags.
+        """
+        return self.__disk.get_flag(flag)
+
+    @localeC
+    def setFlag(self, flag):
+        """Set the flag on this disk.  On error, an Exception will be raised.
+           See getFlag() for more help on working with disk flags."""
+        return self.__disk.set_flag(flag, 1)
+
+    @localeC
+    def unsetFlag(self, flag):
+        """Unset the flag on this disk.  On error, an Exception will be raised.
+           See getFlag() for more help on working with disk flags."""
+        return self.__disk.set_flag(flag, 0)
+
+    @localeC
+    def isFlagAvailable(self, flag):
+        """Return True if flag is available on this Disk, False
+           otherwise."""
+        return self.__disk.is_flag_available(flag)
+
     @property
     def partitions(self):
         """The list of partitions currently on this disk."""
@@ -137,23 +193,26 @@ class Disk(object):
 
     type = property(lambda s: s.__disk.type.name, lambda s, v: setattr(s.__disk, "type", parted.diskType[v]))
 
+    @localeC
     def duplicate(self):
         """Make a deep copy of this Disk."""
         return Disk(PedDisk=self.__disk.duplicate())
 
+    @localeC
     def destroy(self):
         """Closes the Disk ensuring all outstanding writes are flushed."""
         return self.__disk.destroy()
 
+    @localeC
     def commit(self):
         """Writes in-memory changes to a partition table to disk and
            informs the operating system of the changes.  Equivalent to
            calling self.commitToDevice() then self.commitToOS()."""
-        if not self.commitToDevice():
-            return False
+        self.partitions.invalidate()
 
-        return self.commitToOS()
+        return self.__disk.commit()
 
+    @localeC
     def commitToDevice(self):
         """Write the changes made to the in-memory description of a
            partition table to the device."""
@@ -161,6 +220,7 @@ class Disk(object):
 
         return self.__disk.commit_to_dev()
 
+    @localeC
     def commitToOS(self):
         """Tell the operating system kernel about the partition table
            layout of this Disk."""
@@ -168,19 +228,24 @@ class Disk(object):
 
         return self.__disk.commit_to_os()
 
+    @localeC
     def check(self):
         """Perform a sanity check on the partition table of this Disk."""
         return self.__disk.check()
 
+    @localeC
     def supportsFeature(self, feature):
         """Check that the disk type supports the provided feature."""
         return self.__disk.type.check_feature(feature)
 
+    @localeC
     def addPartition(self, partition=None, constraint=None):
         """Add a new Partition to this Disk with the given Constraint."""
         if constraint:
             result = self.__disk.add_partition(partition.getPedPartition(),
                                                constraint.getPedConstraint())
+        elif not partition:
+            raise parted.DiskException, "no partition or constraint specified"
         else:
             result = self.__disk.add_partition(partition.getPedPartition())
 
@@ -191,18 +256,23 @@ class Disk(object):
         else:
             return False
 
+    @localeC
     def removePartition(self, partition=None):
         """Removes specified Partition from this Disk.  NOTE:  If the
            Partition is an extended partition, it must not contain any
            logical partitions.  Also note that the partition is not
            actually destroyed unless you use the deletePartition()
            method."""
+        if not partition:
+            raise parted.DiskException, "no partition specified"
+
         if self.__disk.remove_partition(partition.getPedPartition()):
             self.partitions.invalidate()
             return True
         else:
             return False
 
+    @localeC
     def deletePartition(self, partition):
         """Removes specified Partition from this Disk under the same
            conditions as removePartition(), but also destroy the
@@ -213,6 +283,7 @@ class Disk(object):
         else:
             return False
 
+    @localeC
     def deleteAllPartitions(self):
         """Removes and destroys all Partitions in this Disk."""
         if self.__disk.delete_all():
@@ -221,32 +292,48 @@ class Disk(object):
         else:
             return False
 
+    @localeC
     def setPartitionGeometry(self, partition=None, constraint=None, start=None, end=None):
         """Sets the Geometry of the specified Partition using the given
            Constraint and start and end sectors.  Note that this method
            does not modify the partition contents, just the partition
            table."""
+        if not partition or not constraint:
+            raise parted.DiskException, "no partition or constraint specified"
+
+        if not start or not end:
+            raise parted.DiskException, "no start or end geometry specified"
+
         return self.__disk.set_partition_geom(partition.getPedPartition(),
                                               constraint.getPedConstraint(),
                                               start, end)
 
+    @localeC
     def maximizePartition(self, partition=None, constraint=None):
         """Grow the Partition's Geometry to the maximum possible subject
            to Constraint."""
+        if not partition:
+            raise parted.DiskException, "no partition specified"
+
         if constraint:
             return self.__disk.maximize_partition(partition.getPedPartition(),
                                                   constraint.getPedConstraint())
         else:
             return self.__disk.maximize_partition(partition.getPedPartition())
 
+    @localeC
     def calculateMaxPartitionGeometry(self, partition=None, constraint=None):
         """Get the maximum Geometry the Partition can be grown to,
            subject to the given Constraint."""
+        if not partition:
+            raise parted.DiskException, "no partition specified"
+
         if constraint:
             return parted.Geometry(PedGeometry=self.__disk.get_max_partition_geometry(partition.getPedPartition(), constraint.getPedConstraint()))
         else:
             return parted.Geometry(PedGeometry=self.__disk.get_max_partition_geometry(partition.getPedPartition()))
 
+    @localeC
     def minimizeExtendedPartition(self):
         """Reduce the size of the extended partition to a minimum while
            still wrapping its logical partitions.  If there are no logical
@@ -258,6 +345,7 @@ class Disk(object):
 
         return ret
 
+    @localeC
     def getPartitionBySector(self, sector):
         """Returns the Partition that contains the sector.  If the sector
            lies within a logical partition, then the logical partition is
@@ -296,6 +384,7 @@ class Disk(object):
         # logicals?  probably safer to just use something reasonable
         return 11
 
+    @localeC
     def getExtendedPartition(self):
         """Return the extended Partition, if any, on this Disk."""
         try:
@@ -322,6 +411,7 @@ class Disk(object):
         """Return a list of physical volume-type Partitions on this Disk."""
         return self.__filterPartitions(lambda p: p.active and p.getFlag(parted.PARTITION_LVM))
 
+    @localeC
     def getFreeSpaceRegions(self):
         """Return a list of Geometry objects representing the available
            free space regions on this Disk."""
@@ -336,6 +426,7 @@ class Disk(object):
 
         return freespace
 
+    @localeC
     def getFreeSpacePartitions(self):
         """Return a list of Partition objects representing the available
            free space regions on this Disk."""
@@ -350,11 +441,13 @@ class Disk(object):
 
         return freespace
 
+    @localeC
     def getFirstPartition(self):
         """Return the first Partition object on the disk or None if
            there is not one."""
         return parted.Partition(disk=self, PedPartition=self.__disk.next_partition())
 
+    @localeC
     def getPartitionByPath(self, path):
         """Return a Partition object associated with the partition device
            path, such as /dev/sda1.  Returns None if no partition is found."""
@@ -380,3 +473,16 @@ while True:
         diskType[__type.name] = __type
     except:
         break
+
+# collect all disk flags and store them in a hash
+diskFlag = {}
+__flag = _ped.disk_flag_next(0)
+diskFlag[__flag] = _ped.disk_flag_get_name(__flag)
+__readFlags = True
+
+while __readFlags:
+    __flag = _ped.disk_flag_next(__flag)
+    if not __flag:
+        __readFlags = False
+    else:
+        diskFlag[__flag] = _ped.disk_flag_get_name(__flag)
